### csv_xl_to_mysql
Export Excel or CSV files to MySQL
- This package automatically parses the data types.
- Creates a new database with the specified name or uses the existing one.
- Creates a new table with the specified name or uses the existing one.
- Inserts all the records from the specified CSV/Excel into the table.